@@ -128,7 +128,7 @@ class RibbonBar(QtWidgets.QMenuBar):
     def clear(self):
         raise NotImplementedError("RibbonBar.clear() is not implemented in the ribbon bar.")
 
-    def cornerWidget(self, corner=None):
+    def cornerWidget(self, corner=None, *args, **kwargs):
         raise NotImplementedError("RibbonBar.cornerWidget() is not implemented in the ribbon bar.")
 
     def insertMenu(self, QAction, QMenu):
@@ -146,7 +146,7 @@ class RibbonBar(QtWidgets.QMenuBar):
     def setActiveAction(self, QAction):
         raise NotImplementedError("RibbonBar.setActiveAction() is not implemented in the ribbon bar.")
 
-    def setCornerWidget(self, QWidget, corner=None):
+    def setCornerWidget(self, QWidget, corner=None, *args, **kwargs):
         raise NotImplementedError("RibbonBar.setCornerWidget() is not implemented in the ribbon bar.")
 
     def setDefaultUp(self, up):
@@ -517,8 +517,7 @@ class RibbonBar(QtWidgets.QMenuBar):
 
         :param category: The category to remove.
         """
-        index = self._titleWidget.tabBar().indexOf(category.title())
-        self.tabBar().removeTab(index)
+        self.tabBar().removeTab(self._titleWidget.tabBar().indexOf(category.title()))
         self._stackedWidget.removeWidget(category)
 
     def removeCategories(self, categories: RibbonContextCategories):
@@ -559,10 +558,7 @@ class RibbonBar(QtWidgets.QMenuBar):
 
     def _collapseButtonClicked(self):
         self.tabBar().currentChanged.connect(self.showRibbon)  # type: ignore
-        if self._stackedWidget.isVisible():
-            self.hideRibbon()
-        else:
-            self.showRibbon()
+        self.hideRibbon() if self._stackedWidget.isVisible() else self.showRibbon()
 
     def showRibbon(self):
         """Show the ribbon."""
@@ -580,7 +576,7 @@ class RibbonBar(QtWidgets.QMenuBar):
             self.collapseRibbonButton().setToolTip("Expand Ribbon")
             self.collapseRibbonButton().setIcon(QtGui.QIcon(DataFile("icons/down.png")))
             self._stackedWidget.setVisible(False)
-            self.setFixedSize(self.sizeHint().width(), self._titleWidget.size().height() + 5)
+            self.setFixedSize(self.sizeHint().width(), self._titleWidget.size().height() + 5)  # type: ignore
 
     def ribbonVisible(self) -> bool:
         """Get the visibility of the ribbon.
@@ -594,7 +590,4 @@ class RibbonBar(QtWidgets.QMenuBar):
 
         :param visible: True to show the ribbon, False to hide it.
         """
-        if visible:
-            self.showRibbon()
-        else:
-            self.hideRibbon()
+        self.showRibbon() if visible else self.hideRibbon()
